# js-babel-dev
Consolidated [Babel](https://babeljs.io/) (ES6+) dev-dependencies.

#### IMPORTANT
Do not reference this library unless you are happy staying in lock-step with the babel transpiler plugins used by my [modules](https://github.com/philcockfield/modules) and other idiomatic decisions that I make.


## Install
A single dependency will bring all the standard babel development dependencies:

    npm install --save-dev js-babel-dev


```json
{
  "devDependencies": {
    "js-babel-dev": "^1.0.0"
  }
}

```


## Building ES6 =>ES5
Example of NPM scripts within `package.json` for building ES6+ into a `/lib` folder:

```json
"scripts": {
  "build": "babel src --out-dir lib --source-maps",
  "build:watch": "npm run build -- --watch"
}
```


## Linting
Linting uses the [AirBnB style guide](https://github.com/airbnb/javascript) and corresponding linter.

Add a `.eslint` to your project with the following:

```json
{
  "parser": "babel-eslint",
  "extends": "airbnb"
}

```

##### Why the AirBnB style guide?
When evaluating a [number of JS styleguides](http://noeticforce.com/best-javascript-style-guide-for-maintainable-code) the AirBnB guide was at the top of the list with respect to popularity.  This was echoed in the number of stars on the Github repository (~29K at time or writing) compared to the second most popular style guide ([ideomatic.js](https://github.com/rwaldron/idiomatic.js/)) which sat at ~10k.  

Given styleguides are largely about attempting to standardize to the common norms ("code should look like it was authored by one person") unless the most popular option is flat-out insane, I feel the popularist decision has the most payoff.

Furthermore the AirBnB styleguide seemed to have the most up-to-date support for babel plugins to [Eslint](http://eslint.org/).



## Tests
    npm install
    npm test


---
### License: MIT
